<?php
/**
 * jDiction library entry point
 *
 * @package jDiction
 * @link http://joomla.itronic.at
 * @copyright	Copyright (C) 2011 ITronic Harald Leithner. All rights reserved.
 * @license GNU General Public License v3
 *
 * This file is part of jDiction.
 *
 * jDiction is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * jDiction is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jDiction.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
defined('_JEXEC') or die;

jimport('joomla.form.formfield');
jimport('joomla.form.helper');
JFormHelper::loadFieldClass('multi');


/**
 * Form Field class for the Joomla Platform.
 * Supports a generic Multivalue fieldlist.
 *
 * @package     itrLib
 */
class JFormFieldJDMore extends JFormField
{
  /**
   * The form field type.
   *
   * @var    string
   * @since  11.1
   */
  protected $type = 'JDMore';

  /**
   * Method to get the field input markup for a generic list.
   * Use the multiple attribute to enable multiselect.
   *
   * @return  string  The field input markup.
   *
   * @since   11.1
   */
  protected function getInput()	{

    // Initialize variables.
    $html = array();
    $attr = '';

    // Initialize some field attributes.
    $attr .= $this->element['class'] ? ' class="' . (string) $this->element['class'] . '"' : '';

    // To avoid user's confusion, readonly="true" should imply disabled="true".
    if ((string) $this->element['readonly'] == 'true' || (string) $this->element['disabled'] == 'true') {
      $attr .= ' disabled="disabled"';
    }

    $options = $this->getOptions();
    $values = $this->getValues($options);

    foreach($options as $option) {
      if ((string)$option['type'] != 'hidden') {
        $header[] = '<th>'.JText::_($option['label']).'</th>';
        $header[] = '<th>'.JText::_('LIB_JDICTION_TRANSLATION').'</th>';
      }
    }

    foreach($values as $k=>$row) {

      foreach($row as $value) {
        $field = JFormHelper::loadFieldType($value['type'], true);

        if ($field === false) {
          $field = JFormHelper::loadFieldType('text', true);
        }
        $field->setForm($this->form);

        if ($field->setup($value, (string)$value['value'], (string)$this->element['name'].'.'.$k)) {

          if ((string)$value['type'] != 'trenner' && (string)$value['type'] != 'hidden') {
            $body[$k][] = '<td style="padding: 10px; font-weight: bold;">';
            $body[$k][] = (string)$value['original'];
            $body[$k][] = '</td>';
            $body[$k][] = '<td>';
            $body[$k][] = $field->getInput();
            $body[$k][] = '</td>';
          } else {
            $html[] = $field->getInput();
          }
        }
      }
    }


    $html[] = '<table style="float: left; margin-bottom: 15px" cellpadding="0" cellspacing="0">';
    $html[] = '<tr>';
    $html = array_merge($html, $header);
    $html[] = '</tr>';
    foreach ($body as $k=>$v) {
      $html[] = '<tr>';
      $html = array_merge($html, $v);
      $html[] = '</tr>';
    }
    $html[] = '</table>';

    return implode($html);
  }

  protected function getOptions() {

    $options = array();

    // Get the input fields from XML
    foreach ($this->element->children() as $option) {
      // Only add <option /> elements.
      if ($option->getName() != 'more') {
        continue;
      }

      //change field type from more to field so wie can use JformField
      $fieldvalue = str_replace(array('<more', 'more>'), array('<field', 'field>'), $option->asXML());

      $field = new SimpleXmlElement($fieldvalue);

      $options[] = $field;
    }

    return $options;
  }

  protected function getValues($options) {
    $jd = jDiction::getInstance();

    $table = $this->element['table'] ? (string) $this->element['table'] : false;
    $ordering = $this->element['ordering'] ? (string) $this->element['ordering'] : false;
    $fkidname = $this->element['fkid'] ? (string) $this->element['fkid'] : false;
    $fkid = $this->form->reference->id;
    $pkname = $this->element['key'] ? (string) $this->element['key'] : false;

    $values = array();

    $db = JFactory::getDbo();

    //load original
    $query = $db->getQuery(true);
    $query->select('*');
    $query->from($table);
    $query->where($db->quoteName($fkidname).'='.$fkid);
    if ($ordering) {
      $query->order($ordering);
    }
    $db->setQuery($query);
    $rows = $db->loadAssocList();

    foreach($rows as $row) {
      $translations =  $jd->getTranslation($table, $row[$pkname], $this->form->currentLanguage->lang_id);

      foreach($options as $option) {
        $value = clone $option;
        $value['value'] = $translations[(string)$option['name']];

        $value['original'] = (string)$row[(string)$option['name']];
        $values[(int)$row[$pkname]][(string)$option['name']] = $value;
      }
    }

    return $values;
  }
}